Class: Aws::CodeStar::Types::AssociateTeamMemberRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codestar/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_tokenString

A user- or system-generated token that identifies the entity that requested the team member association to the project. This token can be used to repeat the request.



42
43
44
45
46
47
48
49
50
# File 'lib/aws-sdk-codestar/types.rb', line 42

class AssociateTeamMemberRequest < Struct.new(
  :project_id,
  :client_request_token,
  :user_arn,
  :project_role,
  :remote_access_allowed)
  SENSITIVE = []
  include Aws::Structure
end

#project_idString

The ID of the project to which you will add the IAM user.



42
43
44
45
46
47
48
49
50
# File 'lib/aws-sdk-codestar/types.rb', line 42

class AssociateTeamMemberRequest < Struct.new(
  :project_id,
  :client_request_token,
  :user_arn,
  :project_role,
  :remote_access_allowed)
  SENSITIVE = []
  include Aws::Structure
end

#project_roleString

The AWS CodeStar project role that will apply to this user. This role determines what actions a user can take in an AWS CodeStar project.



42
43
44
45
46
47
48
49
50
# File 'lib/aws-sdk-codestar/types.rb', line 42

class AssociateTeamMemberRequest < Struct.new(
  :project_id,
  :client_request_token,
  :user_arn,
  :project_role,
  :remote_access_allowed)
  SENSITIVE = []
  include Aws::Structure
end

#remote_access_allowedBoolean

Whether the team member is allowed to use an SSH public/private key pair to remotely access project resources, for example Amazon EC2 instances.



42
43
44
45
46
47
48
49
50
# File 'lib/aws-sdk-codestar/types.rb', line 42

class AssociateTeamMemberRequest < Struct.new(
  :project_id,
  :client_request_token,
  :user_arn,
  :project_role,
  :remote_access_allowed)
  SENSITIVE = []
  include Aws::Structure
end

#user_arnString

The Amazon Resource Name (ARN) for the IAM user you want to add to the AWS CodeStar project.



42
43
44
45
46
47
48
49
50
# File 'lib/aws-sdk-codestar/types.rb', line 42

class AssociateTeamMemberRequest < Struct.new(
  :project_id,
  :client_request_token,
  :user_arn,
  :project_role,
  :remote_access_allowed)
  SENSITIVE = []
  include Aws::Structure
end